@@ -5,60 +5,26 @@
 --  This file is going to be executed before any other lua script.
 --  It can be used to load libraries, disable functions and more.
 --
--- $Id$
---
 -- Wireshark - Network traffic analyzer
 -- By Gerald Combs <gerald@wireshark.org>
 -- Copyright 1998 Gerald Combs
 --
--- This program is free software; you can redistribute it and/or
--- modify it under the terms of the GNU General Public License
--- as published by the Free Software Foundation; either version 2
--- of the License, or (at your option) any later version.
---
--- This program is distributed in the hope that it will be useful,
--- but WITHOUT ANY WARRANTY; without even the implied warranty of
--- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--- GNU General Public License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+-- SPDX-License-Identifier: GPL-2.0-or-later
 
--- Set disable_lua to true to disable Lua support.
-disable_lua = false
+-- Set enable_lua to false to disable Lua support.
+enable_lua = true
 
-if disable_lua then
+if not enable_lua then
     return
 end
 
--- If set and we are running with special privileges this setting
--- tells whether scripts other than this one are to be run.
-run_user_scripts_when_superuser = false
+-- If set and Wireshark was started as (setuid) root, then the user
+-- will not be able to execute custom Lua scripts from the personal
+-- configuration directory, the -Xlua_script command line option or
+-- the Lua Evaluate menu option in the GUI.
+run_user_scripts_when_superuser = true
 
 
--- disable potentialy harmful lua functions when running superuser
-if running_superuser then
-    local hint = "has been disabled due to running Wireshark as superuser. See http://wiki.wireshark.org/CaptureSetup/CapturePrivileges for help in running Wireshark as an unprivileged user."
-    local disabled_lib = {}
-    setmetatable(disabled_lib,{ __index = function() error("this package ".. hint) end } );
-
-    dofile = function() error("dofile " .. hint) end
-    loadfile = function() error("loadfile " .. hint) end
-    loadlib = function() error("loadlib " .. hint) end
-    require = function() error("require " .. hint) end
-    os = disabled_lib
-    io = disabled_lib
-    file = disabled_lib
-end
-
--- to avoid output to stdout which can cause problems lua's print ()
--- has been suppresed so that it yields an error.
--- have print() call info() instead.
-if gui_enabled() then
-    print = info
-end
-
 function typeof(obj)
     local mt = getmetatable(obj)
     return mt and mt.__typeof or obj.__typeof or type(obj)
@@ -88,7 +54,6 @@ end
 --
 -- since 1.11.3
 function package.prepend_path(name)
-    local debug = require "debug"
     -- get the function calling this package.prepend_path function
     local dt = debug.getinfo(2, "f")
     if not dt then
@@ -111,7 +76,7 @@ function package.prepend_path(name)
     package.path = name .. sep .. "?.lua;" .. package.path
 end
 
--- -- Wiretap encapsulations XXX
+-- Wiretap encapsulations XXX
 wtap_encaps = {
 	["PER_PACKET"] = -1,
 	["UNKNOWN"] = 0,
@@ -206,7 +171,7 @@ wtap_encaps = {
 	["CATAPULT_DCT2000"] = 89,
 	["BER"] = 90,
 	["JUNIPER_VP"] = 91,
-	["USB"] = 92,
+	["USB_FREEBSD"] = 92,
 	["IEEE802_16_MAC_CPS"] = 93,
 	["NETTL_RAW_TELNET"] = 94,
 	["USB_LINUX"] = 95,
@@ -251,7 +216,7 @@ wtap_encaps = {
 	["MIME"] = 134,
 	["NETANALYZER"] = 135,
 	["NETANALYZER_TRANSPARENT"] = 136,
-	["IP_OVER_IB"] = 137,
+	["IP_OVER_IB_SNOOP"] = 137,
 	["MPEG_2_TS"] = 138,
 	["PPP_ETHER"] = 139,
 	["NFC_LLCP"] = 140,
@@ -259,41 +224,73 @@ wtap_encaps = {
 	["V5_EF"] = 142,
 	["BACNET_MS_TP_WITH_PHDR"] = 143,
 	["IXVERIWAVE"] = 144,
-	["IEEE_802_11_AIROPEEK"] = 145,
-	["SDH"] = 146,
-	["DBUS"] = 147,
-	["AX25_KISS"] = 148,
-	["AX25"] = 149,
-	["SCTP"] = 150,
-	["INFINIBAND"] = 151,
-	["JUNIPER_SVCS"] = 152,
-	["USBPCAP"] = 153,
-	["RTAC_SERIAL"] = 154,
-	["BLUETOOTH_LE_LL"] = 155,
-	["WIRESHARK_UPPER_PDU"] = 156,
-	["STANAG_4607"] = 157,
-	["STANAG_5066_D_PDU"] = 158,
-	["NETLINK"] = 159,
-	["BLUETOOTH_LINUX_MONITOR"] = 160,
-	["BLUETOOTH_BREDR_BB"] = 161,
-	["BLUETOOTH_LE_LL_WITH_PHDR"] = 162,
-	["NSTRACE_3_0"] = 163,
-	["LOGCAT"] = 164,
-	["LOGCAT_BRIEF"] = 165,
-	["LOGCAT_PROCESS"] = 166,
-	["LOGCAT_TAG"] = 167,
-	["LOGCAT_THREAD"] = 168,
-	["LOGCAT_TIME"] = 169,
-	["LOGCAT_THREADTIME"] = 170,
-	["LOGCAT_LONG"] = 171,
-	["PKTAP"] = 172,
-	["EPON"] = 173,
-	["IPMI_TRACE"] = 174
+	["SDH"] = 145,
+	["DBUS"] = 146,
+	["AX25_KISS"] = 147,
+	["AX25"] = 148,
+	["SCTP"] = 149,
+	["INFINIBAND"] = 150,
+	["JUNIPER_SVCS"] = 151,
+	["USBPCAP"] = 152,
+	["RTAC_SERIAL"] = 153,
+	["BLUETOOTH_LE_LL"] = 154,
+	["WIRESHARK_UPPER_PDU"] = 155,
+	["STANAG_4607"] = 156,
+	["STANAG_5066_D_PDU"] = 157,
+	["NETLINK"] = 158,
+	["BLUETOOTH_LINUX_MONITOR"] = 159,
+	["BLUETOOTH_BREDR_BB"] = 160,
+	["BLUETOOTH_LE_LL_WITH_PHDR"] = 161,
+	["NSTRACE_3_0"] = 162,
+	["LOGCAT"] = 163,
+	["LOGCAT_BRIEF"] = 164,
+	["LOGCAT_PROCESS"] = 165,
+	["LOGCAT_TAG"] = 166,
+	["LOGCAT_THREAD"] = 167,
+	["LOGCAT_TIME"] = 168,
+	["LOGCAT_THREADTIME"] = 169,
+	["LOGCAT_LONG"] = 170,
+	["PKTAP"] = 171,
+	["EPON"] = 172,
+	["IPMI_TRACE"] = 173,
+	["LOOP"] = 174,
+	["JSON"] = 175,
+	["NSTRACE_3_5"] = 176,
+	["ISO14443"] = 177,
+	["GFP_T"] = 178,
+	["GFP_F"] = 179,
+	["IP_OVER_IB_PCAP"] = 180,
+	["JUNIPER_VN"] = 181,
+	["USB_DARWIN"] = 182,
+	["LORATAP"] = 183,
+	["3MB_ETHERNET"] = 184,
+	["VSOCK"] = 185,
+	["NORDIC_BLE"] = 186,
+	["NETMON_NET_NETEVENT"] = 187,
+	["NETMON_HEADER"] = 188,
+	["NETMON_NET_FILTER"] = 189,
+	["NETMON_NETWORK_INFO_EX"] = 190,
+	["MA_WFP_CAPTURE_V4"] = 191,
+	["MA_WFP_CAPTURE_V6"] = 192,
+	["MA_WFP_CAPTURE_2V4"] = 193,
+	["MA_WFP_CAPTURE_2V6"] = 194,
+	["MA_WFP_CAPTURE_AUTH_V4"] = 195,
+	["MA_WFP_CAPTURE_AUTH_V6"] = 196,
+	["JUNIPER_ST"] = 197,
+	["ETHERNET_MPACKET"] = 198,
+	["DOCSIS31_XRA31"] = 199,
+	["DPAUXMON"] = 200,
+	["RUBY_MARSHAL"] = 201,
+	["RFC7468"] = 202,
+	["SYSTEMD_JOURNAL"] = 203,
+	["EBHSCR"] = 204,
+	["VPP"] = 205,
+	["IEEE802_15_4_TAP"] = 206
 }
 wtap = wtap_encaps -- for bw compatibility
 
 
--- -- Wiretap file types
+-- Wiretap file types
 wtap_filetypes = {
 	["UNKNOWN"] = 0,
 	["PCAP"] = 1,
@@ -367,6 +364,16 @@ wtap_filetypes = {
 	["LOGCAT_TIME"] = 72,
 	["LOGCAT_THREADTIME"] = 73,
 	["LOGCAT_LONG"] = 74,
+	["COLASOFT_CAPSA"] = 75,
+	["COLASOFT_PACKET_BUILDER"] = 76,
+	["JSON"] = 77,
+	["NETSCALER_3_5"] = 78,
+	["NETTRACE_3GPP_32_423"] = 79,
+	["MPLOG"] = 80,
+	["DPA400"] = 81,
+	["RFC7468"] = 82,
+	["RUBY_MARSHAL"] = 83,
+	["SYSTEMD_JOURNAL"] = 84,
 	["TSPREC_SEC"] = 0,
 	["TSPREC_DSEC"] = 1,
 	["TSPREC_CSEC"] = 2,
@@ -376,7 +383,18 @@ wtap_filetypes = {
 }
 
 
--- -- Wiretap file comment types
+-- Wiretap timestamp precision types
+wtap_tsprecs = {
+	["SEC"] = 0,
+	["DSEC"] = 1,
+	["CSEC"] = 2,
+	["MSEC"] = 3,
+	["USEC"] = 6,
+	["NSEC"] = 9
+}
+
+
+-- Wiretap file comment types
 wtap_comments = {
 	["PER_SECTION"] = 0x00000001,
 	["PER_INTERFACE"] = 0x00000002,
@@ -384,58 +402,82 @@ wtap_comments = {
 }
 
 
---  -- Field Types
+-- Field Types
 ftypes = {
 	["NONE"] = 0,
 	["PROTOCOL"] = 1,
 	["BOOLEAN"] = 2,
-	["UINT8"] = 3,
-	["UINT16"] = 4,
-	["UINT24"] = 5,
-	["UINT32"] = 6,
-	["UINT64"] = 7,
-	["INT8"] = 8,
-	["INT16"] = 9,
-	["INT24"] = 10,
-	["INT32"] = 11,
-	["INT64"] = 12,
-	["FLOAT"] = 13,
-	["DOUBLE"] = 14,
-	["ABSOLUTE_TIME"] = 15,
-	["RELATIVE_TIME"] = 16,
-	["STRING"] = 17,
-	["STRINGZ"] = 18,
-	["UINT_STRING"] = 19,
-	["ETHER"] = 20,
-	["BYTES"] = 21,
-	["UINT_BYTES"] = 22,
-	["IPv4"] = 23,
-	["IPv6"] = 24,
-	["IPXNET"] = 25,
-	["FRAMENUM"] = 26,
-	["PCRE"] = 27,
-	["GUID"] = 28,
-	["OID"] = 29,
-	["EUI64"] = 30,
-	["AX25"] = 31,
-	["VINES"] = 32,
-	["REL_OID"] = 33,
-	["SYSTEM_ID"] = 34,
-	["STRINGZPAD"] = 35
+	["CHAR"] = 3,
+	["UINT8"] = 4,
+	["UINT16"] = 5,
+	["UINT24"] = 6,
+	["UINT32"] = 7,
+	["UINT40"] = 8,
+	["UINT48"] = 9,
+	["UINT56"] = 10,
+	["UINT64"] = 11,
+	["INT8"] = 12,
+	["INT16"] = 13,
+	["INT24"] = 14,
+	["INT32"] = 15,
+	["INT40"] = 16,
+	["INT48"] = 17,
+	["INT56"] = 18,
+	["INT64"] = 19,
+	["IEEE_11073_SFLOAT"] = 20,
+	["IEEE_11073_FLOAT"] = 21,
+	["FLOAT"] = 22,
+	["DOUBLE"] = 23,
+	["ABSOLUTE_TIME"] = 24,
+	["RELATIVE_TIME"] = 25,
+	["STRING"] = 26,
+	["STRINGZ"] = 27,
+	["UINT_STRING"] = 28,
+	["ETHER"] = 29,
+	["BYTES"] = 30,
+	["UINT_BYTES"] = 31,
+	["IPv4"] = 32,
+	["IPv6"] = 33,
+	["IPXNET"] = 34,
+	["FRAMENUM"] = 35,
+	["PCRE"] = 36,
+	["GUID"] = 37,
+	["OID"] = 38,
+	["EUI64"] = 39,
+	["AX25"] = 40,
+	["VINES"] = 41,
+	["REL_OID"] = 42,
+	["SYSTEM_ID"] = 43,
+	["STRINGZPAD"] = 44,
+	["FCWWN"] = 45
+}
+
+
+-- the following table is since 2.0
+-- Field Type FRAMENUM Types
+frametype = {
+	["NONE"] = 0,
+	["REQUEST"] = 1,
+	["RESPONSE"] = 2,
+	["ACK"] = 3,
+	["DUP_ACK"] = 4,
+	["RETRANS_PREV"] = 5,
+	["RETRANS_NEXT"] = 6
 }
 
 
 -- the following table is since 1.12
--- -- Wiretap record_types
+-- Wiretap record_types
 wtap_rec_types = {
 	["PACKET"] = 0,  -- packet 
 	["FT_SPECIFIC_EVENT"] = 1,  -- file-type-specific event 
 	["FT_SPECIFIC_REPORT"] = 2,  -- file-type-specific report 
+	["SYSCALL"] = 3,  -- system call 
 }
 
 
 -- the following table is since 1.11.3
--- -- Wiretap presence flags
+-- Wiretap presence flags
 wtap_presence_flags = {
 	["TS"] = 1,  -- time stamp 
 	["CAP_LEN"] = 2,  -- captured length separate from on-the-network length 
@@ -446,25 +488,51 @@ wtap_presence_flags = {
 }
 
 
--- -- Display Bases
- base = {
-	["NONE"] = 0,
-	["DEC"] = 1,
-	["HEX"] = 2,
-	["OCT"] = 3,
-	["DEC_HEX"] = 4,
-	["HEX_DEC"] = 5,
-	["CUSTOM"] = 6,
+-- Display Bases
+base = {
+	["NONE"] = 0,  -- none
+	["DEC"] = 1,  -- decimal
+	["HEX"] = 2,  -- hexadecimal
+	["OCT"] = 3,  -- octal
+	["DEC_HEX"] = 4,  -- decimal (hexadecimal)
+	["HEX_DEC"] = 5,  -- hexadecimal (decimal)
+	["CUSTOM"] = 6,  -- call custom routine (in ->strings) to format
+	["ASCII"] = 0,  -- shows non-printable ASCII characters as C-style escapes
+	["UNICODE"] = 7,  -- shows non-printable UNICODE characters as \\uXXXX (XXX for now non-printable characters display depends on UI)
+	["DOT"] = 8,  -- hexadecimal bytes with a period (.) between each byte
+	["DASH"] = 9,  -- hexadecimal bytes with a dash (-) between each byte
+	["COLON"] = 10,  -- hexadecimal bytes with a colon (:) between each byte
+	["SPACE"] = 11,  -- hexadecimal bytes with a space between each byte
+	["NETMASK"] = 12,  -- Used for IPv4 address that shouldn't be resolved (like for netmasks)
+	["PT_UDP"] = 13,  -- UDP port
+	["PT_TCP"] = 14,  -- TCP port
+	["PT_DCCP"] = 15,  -- DCCP port
+	["PT_SCTP"] = 16,  -- SCTP port
+	["OUI"] = 17,  -- OUI resolution
+	["RANGE_STRING"] = 256,  -- Use the supplied range string to convert the field to text
+	["UNIT_STRING"] = 4096,  -- Add unit text to the field value
+	["LOCAL"] = 1000,  -- local time in our time zone, with month and day
+	["UTC"] = 1001,  -- UTC, with month and day
+	["DOY_UTC"] = 1002,  -- UTC, with 1-origin day-of-year
 }
 
 
-
--- -- Encodings
+-- Encodings
 ENC_BIG_ENDIAN = 0
 ENC_LITTLE_ENDIAN = 2147483648
+ENC_TIME_SECS_NSECS = 0
 ENC_TIME_TIMESPEC = 0
 ENC_TIME_NTP = 2
 ENC_TIME_TOD = 4
+ENC_TIME_RTPS = 8
+ENC_TIME_NTP_BASE_ZERO = 8
+ENC_TIME_SECS_USECS = 16
+ENC_TIME_TIMEVAL = 16
+ENC_TIME_SECS = 18
+ENC_TIME_MSECS = 20
+ENC_TIME_SECS_NTP = 24
+ENC_TIME_RFC_3971 = 32
+ENC_TIME_MSEC_NTP = 34
 ENC_CHARENCODING_MASK = 2147483646
 ENC_ASCII = 0
 ENC_UTF_8 = 2
@@ -492,12 +560,20 @@ ENC_EBCDIC = 46
 ENC_MAC_ROMAN = 48
 ENC_CP437 = 50
 ENC_ASCII_7BITS = 52
+ENC_T61 = 54
+ENC_EBCDIC_CP037 = 56
+ENC_ZIGBEE = 58
+ENC_WINDOWS_1251 = 60
+ENC_CP855 = 62
+ENC_CP866 = 64
 ENC_NA = 0
 ENC_STR_NUM = 16777216
 ENC_STR_HEX = 33554432
 ENC_STRING = 50331648
 ENC_STR_MASK = 65534
 ENC_NUM_PREF = 2097152
+ENC_VARINT_PROTOBUF = 2
+ENC_VARINT_QUIC = 4
 ENC_SEP_NONE = 65536
 ENC_SEP_COLON = 131072
 ENC_SEP_DASH = 262144
@@ -513,8 +589,7 @@ ENC_STR_TIME_MASK = 983040
 
 
 
-
--- -- Expert flags and facilities (deprecated - see 'expert' table below)
+-- Expert flags and facilities (deprecated - see 'expert' table below)
 PI_SEVERITY_MASK = 15728640
 PI_COMMENT = 1048576
 PI_CHAT = 2097152
@@ -533,11 +608,14 @@ PI_DEBUG = 134217728
 PI_PROTOCOL = 150994944
 PI_SECURITY = 167772160
 PI_COMMENTS_GROUP = 184549376
+PI_DECRYPTION = 201326592
+PI_ASSUMPTION = 218103808
+PI_DEPRECATED = 234881024
 
 
 
 -- the following table is since 1.11.3
--- -- Expert flags and facilities
+-- Expert flags and facilities
 expert = {
 	-- Expert event groups
 	group = {
@@ -563,6 +641,12 @@ expert = {
 		["SECURITY"] = 167772160,
 		-- The protocol field indicates a packet comment
 		["COMMENTS_GROUP"] = 184549376,
+		-- The protocol field indicates a decryption problem
+		["DECRYPTION"] = 201326592,
+		-- The protocol field has incomplete data, decode based on assumed value
+		["ASSUMPTION"] = 218103808,
+		-- The protocol field has been deprecated, usually PI_NOTE severity
+		["DEPRECATED"] = 234881024,
 	},
 	-- Expert severity levels
 	severity = {
@@ -581,7 +665,7 @@ expert = {
 
 
 
--- -- menu groups for register_menu
+-- menu groups for register_menu
 MENU_ANALYZE_UNSORTED = 0
 MENU_ANALYZE_CONVERSATION = 1
 MENU_STAT_UNSORTED = 2
@@ -590,21 +674,26 @@ MENU_STAT_CONVERSATION = 4
 MENU_STAT_ENDPOINT = 5
 MENU_STAT_RESPONSE = 6
 MENU_STAT_TELEPHONY = 7
-MENU_STAT_TELEPHONY_GSM = 8
-MENU_STAT_TELEPHONY_LTE = 9
-MENU_STAT_TELEPHONY_SCTP = 10
-MENU_TOOLS_UNSORTED = 11
+MENU_STAT_TELEPHONY_ANSI = 8
+MENU_STAT_TELEPHONY_GSM = 9
+MENU_STAT_TELEPHONY_LTE = 10
+MENU_STAT_TELEPHONY_MTP3 = 11
+MENU_STAT_TELEPHONY_SCTP = 12
+MENU_TOOLS_UNSORTED = 13
 
 
 -- other useful constants
+-- DATA_DIR and USER_DIR have a trailing directory separator.
 GUI_ENABLED = gui_enabled()
-DATA_DIR = Dir.global_config_path()
-USER_DIR = Dir.personal_config_path()
+DATA_DIR = Dir.global_config_path()..package.config:sub(1,1)
+USER_DIR = Dir.personal_config_path()..package.config:sub(1,1)
 
 -- deprecated function names
 datafile_path = Dir.global_config_path
 persconffile_path = Dir.personal_config_path
 
 
-dofile(DATA_DIR.."console.lua")
+if not running_superuser or run_user_scripts_when_superuser then
+    dofile(DATA_DIR.."console.lua")
+end
 --dofile(DATA_DIR.."dtd_gen.lua")
